summaryrefslogtreecommitdiff
path: root/source4
diff options
context:
space:
mode:
authorBjörn Baumbach <bb@sernet.de>2019-03-20 17:17:05 +0100
committerAndrew Bartlett <abartlet@samba.org>2019-07-04 02:07:21 +0000
commit78e78a4092569978e79a661bcd6e6631e4868245 (patch)
tree13eb1b4e4ffb95cd32ce0ef57f8814a8cff59683 /source4
parent3f10c8f25cf1655b4facf190f61acb4098919609 (diff)
downloadsamba-78e78a4092569978e79a661bcd6e6631e4868245.tar.gz
samba-tool tests: add tests for contact management
Signed-off-by: Björn Baumbach <bb@samba.org> Reviewed-by: Andrew Bartlett <abartlet@samba.org>
Diffstat (limited to 'source4')
-rwxr-xr-xsource4/selftest/tests.py3
1 files changed, 2 insertions, 1 deletions
diff --git a/source4/selftest/tests.py b/source4/selftest/tests.py
index 67e33fc37dc..6216ee52150 100755
--- a/source4/selftest/tests.py
+++ b/source4/selftest/tests.py
@@ -659,11 +659,12 @@ planpythontestsuite("none", "samba.tests.samba_tool.visualize")
for env in all_fl_envs:
planpythontestsuite(env + ":local", "samba.tests.samba_tool.fsmo")
# test samba-tool user, group and computer edit command
for env in all_fl_envs:
env += ":local"
plantestsuite("samba.tests.samba_tool.user_edit", env, [os.path.join(srcdir(), "python/samba/tests/samba_tool/user_edit.sh"), '$SERVER', '$USERNAME', '$PASSWORD'])
plantestsuite("samba.tests.samba_tool.group_edit", env, [os.path.join(srcdir(), "python/samba/tests/samba_tool/group_edit.sh"), '$SERVER', '$USERNAME', '$PASSWORD'])
+ plantestsuite("samba.tests.samba_tool.contact_edit", env, [os.path.join(srcdir(), "python/samba/tests/samba_tool/contact_edit.sh"), '$SERVER', '$USERNAME', '$PASSWORD'])
plantestsuite("samba.tests.samba_tool.computer_edit", env, [os.path.join(srcdir(), "python/samba/tests/samba_tool/computer_edit.sh"), '$SERVER', '$USERNAME', '$PASSWORD'])
# We run this test against both AD DC implementations because it is
@@ -659,11 +659,12 @@ planpythontestsuite("none", "samba.tests.samba_tool.visualize")
for env in all_fl_envs:
planpythontestsuite(env + ":local", "samba.tests.samba_tool.fsmo")
-# test samba-tool user, group and computer edit command
+# test samba-tool user, group, contact and computer edit command
for env in all_fl_envs:
env += ":local"